@import "base";

@primary: #409eff !important;
@color: white;

@menu-color: #606266 !important;
@menu-background: #ebf1f5 !important;

@menu-color-hover: #696969;
@menu-background-hover: hsla(0, 0%, 100%, .5);

@menu-title-color: #606266;
@menu-title-background-color: #ebf1f5;

@menu-title-color-hover: #666;
@menu-title-background-color-hover: hsla(0, 0%, 100%, .5);


@navbar-color: #606266;
@navbar-background: #ebf1f5;