@import "e-blue-pro";

@primary: #1E9FFF !important;
@navbar-background: #FFF;
@navbar-color: #303133;
.navbar .el-button:focus, .navbar .el-button:hover {
  color: rgba(@navbar-color, 0.8) !important;
}